==> mudlet_3.2.0.orig.tar.xz: mudlet-3.2.0/src/dlgColorTrigger.h <==
#ifndef MUDLET_DLGCOLORTRIGGER_H
#define MUDLET_DLGCOLORTRIGGER_H

/***************************************************************************
 *   Copyright (C) 2008-2009 by Heiko Koehn - KoehnHeiko@googlemail.com    *
 *   Copyright (C) 2014 by Ahmed Charles - acharles@outlook.com            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "pre_guard.h"
#include "ui_color_trigger.h"
#include "post_guard.h"

class Host;
class TTrigger;


class dlgColorTrigger : public QDialog, public Ui::color_trigger_dlg
{
    Q_OBJECT

    Q_DISABLE_COPY(dlgColorTrigger)

public:
    dlgColorTrigger(QWidget*, TTrigger*, int);

public slots:
    void setColorBlack();
    void setColorLightBlack();
    void setColorRed();
    void setColorLightRed();
    void setColorBlue();
    void setColorLightBlue();
    void setColorGreen();
    void setColorLightGreen();
    void setColorYellow();
    void setColorLightYellow();
    void setColorCyan();
    void setColorLightCyan();
    void setColorMagenta();
    void setColorLightMagenta();
    void setColorWhite();
    void setColorLightWhite();

    void slot_save_and_exit();

private:
    TTrigger* mpTrigger;
    int mMode;
};

#endif // MUDLET_DLGCOLORTRIGGER_H

==> mudlet_3.7.1.orig.tar.xz: mudlet-3.7.1/src/dlgColorTrigger.h <==
#ifndef MUDLET_DLGCOLORTRIGGER_H
#define MUDLET_DLGCOLORTRIGGER_H

/***************************************************************************
 *   Copyright (C) 2008-2009 by Heiko Koehn - KoehnHeiko@googlemail.com    *
 *   Copyright (C) 2014 by Ahmed Charles - acharles@outlook.com            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "pre_guard.h"
#include "ui_color_trigger.h"
#include "post_guard.h"

class Host;
class TTrigger;


class dlgColorTrigger : public QDialog, public Ui::color_trigger
{
    Q_OBJECT

public:
    Q_DISABLE_COPY(dlgColorTrigger)
    dlgColorTrigger(QWidget*, TTrigger*, int);

public slots:
    void setColorBlack();
    void setColorLightBlack();
    void setColorRed();
    void setColorLightRed();
    void setColorBlue();
    void setColorLightBlue();
    void setColorGreen();
    void setColorLightGreen();
    void setColorYellow();
    void setColorLightYellow();
    void setColorCyan();
    void setColorLightCyan();
    void setColorMagenta();
    void setColorLightMagenta();
    void setColorWhite();
    void setColorLightWhite();

    void slot_save_and_exit();

private:
    TTrigger* mpTrigger;
    int mMode;
};

#endif // MUDLET_DLGCOLORTRIGGER_H
